@@ -8,38 +8,39 @@ use 5.010;
 use Moose::Role;
 use App::TimeTracker::Utils qw(pretty_date);
 
-after ['cmd_start','cmd_stop','cmd_current','cmd_continue'] => sub {
+after [ 'cmd_start', 'cmd_stop', 'cmd_current', 'cmd_continue' ] => sub {
     my $self = shift;
     $self->_update_text_notify();
 };
 
 sub _update_text_notify {
     my $self = shift;
-    
+
     my $notify_file = $self->home->file('current.txt');
-    
-    if (my $task = App::TimeTracker::Data::Task->current($self->home)) {
-        my $fh = $notify_file->openw();
-        my $text = $task->project.' since '.pretty_date($task->start);
-        
-        if ($task->can('rt_id')
-            && $task->rt_id) {
+
+    if ( my $task = App::TimeTracker::Data::Task->current( $self->home ) ) {
+        my $fh   = $notify_file->openw();
+        my $text = $task->project . ' since ' . pretty_date( $task->start );
+
+        if (   $task->can('rt_id')
+            && $task->rt_id )
+        {
             $text .= "\nRT" . $task->rt_id;
-            $text .= ": ".$task->description if $task->description;
+            $text .= ": " . $task->description if $task->description;
         }
-        elsif (my $desc = $task->description) {
-            $text .= $desc
+        elsif ( my $desc = $task->description ) {
+            $text .= $desc;
         }
         print $fh $text;
         say $text;
         $fh->close;
-    } else {
+    }
+    else {
         $notify_file->remove()
             if -e $notify_file;
     }
 }
 
-
 no Moose::Role;
 1;
 
@@ -53,7 +54,7 @@ App::TimeTracker::Command::TextNotify - App::TimeTracker post mac desktop integr
 
 =head1 VERSION
 
-version 2.018
+version 2.019
 
 =head1 AUTHOR
 
