@@ -11,38 +11,47 @@ use Term::ANSIColor;
 use Exporter;
 use parent qw(Exporter);
 
-our @EXPORT = qw();
-our @EXPORT_OK = qw(pretty_date now error_message);
-our %EXPORT_TAGS = (
-    all => \@EXPORT_OK
-);
+our @EXPORT      = qw();
+our @EXPORT_OK   = qw(pretty_date now error_message warning_message);
+our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
 sub error_message {
-    my ($message,@params) = @_;
+    return _message( 'bold red', @_ );
+}
 
-    # TODO better error handling
-    my $error = sprintf($message,@params);
+sub warning_message {
+    return _message( 'bold yellow', @_ );
+}
 
-    print color 'bold red';
-    print $error;
+sub _message {
+    my ( $color, $message, @params ) = @_;
+
+    my $string = sprintf( $message, @params );
+
+    print color $color;
+    print $string;
     say color 'reset';
 }
 
 sub pretty_date {
     my ($date) = @_;
-    
-    unless (blessed $date
-        && $date->isa('DateTime')) {
+
+    unless ( blessed $date
+        && $date->isa('DateTime') )
+    {
         return $date;
-    } else {
+    }
+    else {
         my $now = now();
-        my $yeseterday = now()->subtract( days => 1);
-        if ($date->dmy eq $now->dmy) {
+        my $yeseterday = now()->subtract( days => 1 );
+        if ( $date->dmy eq $now->dmy ) {
             return $date->hms(':');
-        } elsif ($date->dmy eq $yeseterday->dmy) {
-            return 'yesterday '.$date->hms(':');
-        } else {
-            return $date->dmy('.').' '.$date->hms(':');
+        }
+        elsif ( $date->dmy eq $yeseterday->dmy ) {
+            return 'yesterday ' . $date->hms(':');
+        }
+        else {
+            return $date->dmy('.') . ' ' . $date->hms(':');
         }
     }
 }
@@ -64,7 +73,7 @@ App::TimeTracker::Utils - Utility Methods/Functions for App::TimeTracker
 
 =head1 VERSION
 
-version 2.018
+version 2.019
 
 =head1 AUTHOR
 
